==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Kompletny</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Ograniczenie osi...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>ustaw ograniczenie osi między dwoma obiektami</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Autotest...</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Wykonanie autotestu w celu sprawdzenia poprawności aplikacji.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>Rysow&amp;anie</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>Sz&amp;kic</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Kreślenie</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Ze szkicu</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Proste kształty</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Parametryczny</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Wygląd obiektu</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Narzędzia Szkieletu</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Kompletny</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Ograniczenie osi...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>ustaw ograniczenie osi między dwoma obiektami</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Autotest...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Wykonanie autotestu w celu sprawdzenia poprawności działania aplikacji.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>Rysow&amp;anie</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>Sz&amp;kic</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>Raytracing</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Kreślenie</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Ze szkicu</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Początkowe</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Parametryczny</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Wygląd obiektu</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Narzędzia Szkieletu</translation>
    </message>
  </context>
</TS>
